@@ -28,13 +28,30 @@ check_RoBMA_convergence <- function(fit){
   return(.get_model_convergence(fit))
 }
 
-
+# Internal function for re-evaluating model convergence with updated criteria:
+# Purpose: Allows post-hoc changes to convergence diagnostics without refitting
+# 
+# Process:
+# 1. Extracts MCMC fit and marginal likelihood from model object
+# 2. Skips evaluation for error/null models (automatically non-converged)
+# 3. Re-runs JAGS convergence diagnostics with new thresholds
+# 4. For bridge sampling: validates marginal likelihood computation
+# 5. Updates model convergence status and error/warning messages
+#
+# Key behaviors:
+# - Bridge sampling requires both MCMC convergence AND valid marginal likelihood
+# - Spike-and-slab (ss) only requires MCMC convergence 
+# - Failed models can be kept or removed based on remove_failed setting
+# - Aggregates warnings from MCMC fitting, convergence checks, and marginal likelihood
+#
+# This enables users to adjust convergence criteria after model fitting
+# without requiring computationally expensive re-fitting
 .update_model_checks       <- function(model, convergence_checks, algorithm = "bridge"){
 
   fit     <- model[["fit"]]
   marglik <- model[["marglik"]]
 
-  # skip models with an error or emty models
+  # Skip models that failed to fit or are null models (automatically non-converged)
   if(inherits(fit, "error") || inherits(fit, "null_model")){
     return(model)
   }
@@ -42,52 +59,80 @@ check_RoBMA_convergence <- function(fit){
   errors    <- NULL
   warnings  <- NULL
 
-  # re-evaluate convergence checks with the new settigns
+  # Re-evaluate MCMC convergence diagnostics with updated criteria
+  # Uses BayesTools to check Rhat, ESS, and Monte Carlo error thresholds
   check_fit     <- BayesTools::JAGS_check_convergence(
     fit          = fit,
     prior_list   = attr(fit, "prior_list"),
-    max_Rhat     = convergence_checks[["max_Rhat"]],
-    min_ESS      = convergence_checks[["min_ESS"]],
-    max_error    = convergence_checks[["max_error"]],
-    max_SD_error = convergence_checks[["max_SD_error"]]
+    max_Rhat     = convergence_checks[["max_Rhat"]],      # Gelman-Rubin statistic threshold
+    min_ESS      = convergence_checks[["min_ESS"]],       # Effective sample size minimum
+    max_error    = convergence_checks[["max_error"]],     # Monte Carlo standard error maximum
+    max_SD_error = convergence_checks[["max_SD_error"]]   # SD of MC error maximum
   )
+  
+  # Aggregate warnings from fit and convergence check
   warnings    <- c(warnings, attr(fit, "warnings"), attr(check_fit, "errors"))
+  
+  # Determine convergence based on MCMC diagnostics and user preferences
   if(convergence_checks[["remove_failed"]] && !check_fit){
     converged <- FALSE
   }else{
     converged <- TRUE
   }
 
+  # Bridge sampling algorithm requires additional marginal likelihood validation
+  # Spike-and-slab (ss) algorithm doesn't use marginal likelihoods
   if(algorithm == "bridge"){
-    # check the marginal likelihood and keep the errors
+    # Check that marginal likelihood computation succeeded
     if(is.na(marglik$logml)){
       errors         <- c(errors, attr(marglik, "errors"))
-      converged      <- FALSE
+      converged      <- FALSE  # Failed marginal likelihood = non-converged model
     }else{
-      # forward warnings if present
+      # Forward any marginal likelihood warnings (but don't fail the model)
       warnings <- c(warnings, attr(marglik, "warnings"))
     }
   }
 
-
+  # Update model object with new convergence assessment
   model$errors    <- errors
   model$warnings  <- warnings
   model$converged <- converged
 
   return(model)
 }
+# Internal function to determine if a model has only constant (point) priors:
+# Purpose: Identifies models that don't require MCMC sampling because all parameters are fixed
+#
+# Logic:
+# - Simple models: all priors must be point/none AND no publication bias (omega) priors
+# - Regression models: all non-term priors must be point/none AND all term priors must be point 
+#   AND no publication bias priors
+#
+# Key concepts:
+# - Point priors: fix parameter to specific value (no uncertainty)
+# - None priors: parameter not included in model
+# - If all parameters are fixed, no MCMC sampling needed (analytical solution)
+# - Publication bias (omega) priors require sampling even if other priors are point
+#
+# Returns: TRUE if model is constant (no sampling needed), FALSE otherwise
 .is_model_constant         <- function(priors){
-  # checks whether there is at least one non-nill prior
+  
   if(is.null(priors[["terms"]])){
-    # in simple models
-    return(all(sapply(priors, function(prior) is.prior.point(prior) | is.prior.none(prior))) & is.null(priors[["omega"]]))
+    # Simple (non-regression) models: check all components except terms
+    # Must have no omega priors (publication bias requires sampling)
+    return(all(sapply(priors, function(prior) is.prior.point(prior) | is.prior.none(prior))) && is.null(priors[["omega"]]))
   }else{
-    # in regression models
-    non_terms <- all(sapply(priors[names(priors) != "terms"], function(prior) is.prior.point(prior) | is.prior.none(prior))) & is.null(priors[["omega"]])
+    # Regression models: separate checks for non-term and term priors
+    # Non-term priors (effect, heterogeneity, etc.): can be point or none, no omega allowed
+    non_terms <- all(sapply(priors[names(priors) != "terms"], function(prior) is.prior.point(prior) | is.prior.none(prior))) && is.null(priors[["omega"]])
+    
+    # Term priors (regression coefficients): must all be point priors (not none)
+    # Regression coefficients can't be "none" - they must be either estimated or fixed
     terms     <- all(sapply(priors[["terms"]], function(prior) is.prior.point(prior)))
+    
+    # Both conditions must be satisfied for model to be constant
     return(non_terms && terms)
   }
-  return()
 }
 .remove_model_posteriors   <- function(object){
   for(i in seq_along(object[["models"]])){
@@ -142,6 +187,18 @@ check_RoBMA_convergence <- function(fit){
     return(NULL)
   }
 }
+# Internal function to aggregate and format errors/warnings for user display:
+# Purpose: Collects errors, warnings, and convergence issues across all models
+# 
+# Process:
+# 1. Shortens long warning/error lists to manageable size (max_print limit)
+# 2. Adds convergence failure summary if any models failed
+# 3. Returns formatted message vector for user feedback
+#
+# Design rationale:
+# - Users shouldn't be overwhelmed with hundreds of similar warnings
+# - Convergence failures are critical and always reported
+# - Full details available via check_RoBMA() for debugging
 .collect_errors_and_warnings <- function(object, max_print = 5){
 
   short_warnings <- .shorten_warnings(object$add_info[["warnings"]], max_print)
@@ -150,24 +207,50 @@ check_RoBMA_convergence <- function(fit){
 
   return(c(short_warnings, short_errors, conv_warning))
 }
+
+# Internal function to extract convergence status across different algorithms:
+# Purpose: Returns logical vector indicating which models converged successfully
+#
+# Algorithm differences:
+# - Bridge sampling: multiple models stored in object[["models"]], each with convergence status  
+# - Spike-and-slab: single model stored in object[["model"]] with single convergence status
+#
+# Returns: logical vector (bridge) or single logical value (ss) indicating convergence
 .get_model_convergence       <- function(object){
   if(object$add_info[["algorithm"]] == "bridge"){
+    # Bridge sampling: check convergence status for each model in the ensemble
+    # Returns logical vector with length = number of models
     return(sapply(object[["models"]], function(model) if(is.null(model[["converged"]])) FALSE else model[["converged"]]))
   }else if(object$add_info[["algorithm"]] == "ss"){
+    # Spike-and-slab: single model convergence status
+    # Returns single logical value
     return(if(is.null(object[["model"]][["converged"]])) FALSE else object[["model"]][["converged"]])
   }
 }
+
+# Internal function to extract warnings from models with algorithm-specific formatting:
+# Purpose: Collects all warning messages across fitted models for user feedback
+# 
+# Formatting differences:
+# - Bridge sampling: prefixes warnings with "Model (i):" to identify source model
+# - Spike-and-slab: returns warnings directly (only one model)
 .get_model_warnings          <- function(object){
   if(object$add_info[["algorithm"]] == "bridge"){
+    # Bridge sampling: format warnings with model index for identification
     return(unlist(sapply(seq_along(object[["models"]]), function(i){
       if(!is.null(object[["models"]][[i]][["warnings"]])){
         paste0("Model (", i, "): ", object[["models"]][[i]][["warnings"]])
       }
     })))
   }else if(object$add_info[["algorithm"]] == "ss"){
+    # Spike-and-slab: direct warning passthrough
     return(object[["model"]][["warnings"]])
   }
 }
+
+# Internal function to extract errors from models with algorithm-specific formatting:
+# Purpose: Collects all error messages across fitted models for debugging
+# Same formatting logic as warnings but for errors
 .get_model_errors            <- function(object){
   if(object$add_info[["algorithm"]] == "bridge"){
     return(unlist(sapply(seq_along(object[["models"]]), function(i){
@@ -205,44 +288,67 @@ check_RoBMA_convergence <- function(fit){
   }
 
 }
+# Internal function to determine if a model component is specified as "null":
+# Purpose: Checks if effect, heterogeneity, bias, or hierarchical components are absent
+#
+# Component-specific logic:
+# - Effect: checks mu (simple models) or intercept (regression models)
+# - Heterogeneity: checks tau parameter 
+# - Bias: checks omega (publication bias) parameter
+# - Hierarchical: checks rho (between-study correlation) parameter
+#
+# Key concepts:
+# - NULL prior: component not included in model at all
+# - is_null flag: component included but set to test null hypothesis (typically point prior at 0)
+# - Simple vs regression models have different parameter structures
+#
+# Returns: TRUE if component represents null hypothesis, FALSE if alternative hypothesis
 .is_component_null           <- function(priors, component){
   if(component == "effect"){
     if(is.null(priors[["terms"]])){
+      # Simple models: check mu parameter directly
       if(is.null(priors[["mu"]])){
-        return(TRUE)
+        return(TRUE)  # No effect parameter = null effect
       }else{
-        return(priors[["mu"]][["is_null"]])
+        return(priors[["mu"]][["is_null"]])  # Check if effect is set to null (e.g., point prior at 0)
       }
     }else{
+      # Regression models: effect is represented by intercept term
       return(priors[["terms"]][["intercept"]][["is_null"]])
     }
   }else if(component == "heterogeneity"){
+    # Heterogeneity: tau parameter controls between-study variance
     if(is.null(priors[["tau"]])){
-      return(TRUE)
+      return(TRUE)  # No tau = homogeneous effects (null heterogeneity)
     }else{
-      return(priors[["tau"]][["is_null"]])
+      return(priors[["tau"]][["is_null"]])  # Check if tau set to null (typically point prior at 0)
     }
   }else if(component == "baseline"){
+    # Baseline: pi parameter for baseline event rates in BiBMA models
     if(is.null(priors[["pi"]])){
-      return(TRUE)
+      return(TRUE)  # No baseline parameter specified
     }else{
-      return(priors[["pi"]][["is_null"]])
+      return(priors[["pi"]][["is_null"]])  # Check if baseline is null
     }
   }else if(component == "hierarchical"){
+    # Hierarchical: rho parameter for between-study correlations in multilevel models
+    # Special logic: hierarchical models require both tau > 0 AND rho parameter
     if((is.prior.point(priors[["tau"]]) && priors[["tau"]]$parameters[["location"]] == 0) || is.null(priors[["rho"]])){
-      return(TRUE)
+      return(TRUE)  # No hierarchical structure if tau=0 or no rho parameter
     }else{
-      return(priors[["rho"]][["is_null"]])
+      return(priors[["rho"]][["is_null"]])  # Check if rho set to null
     }
   }else if(component == "bias"){
+    # Publication bias: can be modeled via omega (weight functions), PET, or PEESE
+    # Check for any bias parameter in order of preference
     if(!is.null(priors[["omega"]])){
-      return(priors[["omega"]][["is_null"]])
+      return(priors[["omega"]][["is_null"]])  # Weight functions
     }else if(!is.null(priors[["PET"]])){
-      return(priors[["PET"]][["is_null"]])
+      return(priors[["PET"]][["is_null"]])    # PET models
     }else if(!is.null(priors[["PEESE"]])){
-      return(priors[["PEESE"]][["is_null"]])
+      return(priors[["PEESE"]][["is_null"]])  # PEESE models
     }else{
-      return(TRUE)
+      return(TRUE)  # No bias parameters = null bias
     }
   }
 }
@@ -405,6 +511,13 @@ check_RoBMA_convergence <- function(fit){
 .is_regression   <- function(object){
   return(!is.null(object[["formula"]]))
 }
+.get_outcome_data <- function(object){
+  if(.is_regression(object)){
+    return(object$data[["outcome"]])
+  }else{
+    return(object[["data"]])
+  }
+}
 
 # parameter naming functions
 .BayesTools_parameter_name    <- function(parameter){
@@ -419,6 +532,18 @@ check_RoBMA_convergence <- function(fit){
 .output_parameter_names       <- function(parameter){
   return(BayesTools::format_parameter_names(parameter, formula_parameters = "mu", formula_prefix = FALSE))
 }
+# Internal function returning reserved keywords that cannot be used as predictor names:
+# Purpose: Prevents naming conflicts between user predictors and internal parameters
+#
+# Categories of reserved words:
+# 1. JAGS parameter names: mu, tau, theta, omega, rho, eta, PET, PEESE, pi, gamma
+# 2. Internal component names: intercept, terms, component_*
+# 3. Model type identifiers: weightfunction, PET-PEESE, etc.
+# 4. Data column names: d, t, r, z, y, logOR, OR, lCI, uCI, v, se, n, weight, x1, x2, n1, n2
+# 5. Component identifiers: component_effect, component_heterogeneity, etc.
+#
+# Using these names as predictors would cause conflicts in JAGS model code generation
+# or internal data processing, leading to unpredictable behavior
 .reserved_words               <- function() c("intercept", "Intercept", "terms", "mu", "tau", "theta", "omega", "rho", "eta", "PET", "PEESE", "pi", "gamma",
                                               "weightfunction", "weigthfunction", "PET-PEESE", "PETPEESE",
                                               "d", "t", "r", "z", "y", "logOR", "OR", "lCI", "uCI", "v", "se", "n", "weight", "x1", "x2", "n1", "n2",
